@@ -1198,24 +1198,28 @@ class LogManager(object):
                 self.logger.removeHandler(handler)
 
     def __add_a_hanlder(self, handlerx: logging.Handler):
-        for hdlr in self.logger.handlers:
-            if type(hdlr) == type(handlerx):
-                return
+        if self.__judge_has_handler_type(type(handlerx)):
+            return
         handlerx.setLevel(10)
         handlerx.setFormatter(self._formatter)
         self.logger.addHandler(handlerx)
 
+    def __judge_has_handler_type(self, handler_type: type):
+        for hr in self.logger.handlers:
+            if isinstance(hr, handler_type):
+                return True
+
     def __add_handlers(self):
         pass
 
         # REMIND 添加控制台日志
-        if self._is_add_stream_handler:
+        if not (self.__judge_has_handler_type(ColorHandler) or self.__judge_has_handler_type(logging.StreamHandler)) and self._is_add_stream_handler:
             handler = ColorHandler(is_pycharm_2019=self._is_pycharm_2019) if not self._do_not_use_color_handler else logging.StreamHandler()  # 不使用streamhandler，使用自定义的彩色日志
             # handler = logging.StreamHandler()
             self.__add_a_hanlder(handler)
 
         # REMIND 添加多进程安全切片的文件日志
-        if all([self._log_path, self._log_filename]):
+        if not self.__judge_has_handler_type(ConcurrentRotatingFileHandler) and all([self._log_path, self._log_filename]):
             if not os.path.exists(self._log_path):
                 os.makedirs(self._log_path)
             log_file = os.path.join(self._log_path, self._log_filename)
@@ -1242,6 +1246,27 @@ class LogManager(object):
                                                                                              backupCount=3, encoding="utf-8")
             self.__add_a_hanlder(rotate_file_handler)
 
+        # REMIND 添加mongo日志。
+        if not self.__judge_has_handler_type(MongoHandler) and self._mongo_url:
+            self.__add_a_hanlder(MongoHandler(self._mongo_url))
+
+        # REMIND 添加es日志。
+        # if app_config.env == 'test' and self._is_add_elastic_handler:
+        if not self.__judge_has_handler_type(ElasticHandler) and app_config.env == 'testxxx':  # 使用kafka。不直接es。
+            """
+            生产环境使用阿里云 oss日志，不使用这个。
+            """
+            self.__add_a_hanlder(ElasticHandler([ELASTIC_HOST], ELASTIC_PORT))
+
+        # REMIND 添加kafka日志。
+        # if self._is_add_kafka_handler:
+        if not self.__judge_has_handler_type(KafkaHandler) and app_config.env == 'test' and ALWAYS_ADD_KAFKA_HANDLER_IN_TEST_ENVIRONENT:
+            self.__add_a_hanlder(KafkaHandler(KAFKA_BOOTSTRAP_SERVERS, ))
+
+        # REMIND 添加钉钉日志。
+        if not self.__judge_has_handler_type(DingTalkHandler) and self._ding_talk_token:
+            self.__add_a_hanlder(DingTalkHandler(self._ding_talk_token, self._ding_talk_time_interval))
+
         # REMIND 添加mongo日志。
         if self._mongo_url:
             self.__add_a_hanlder(MongoHandler(self._mongo_url))
@@ -1500,10 +1525,10 @@ class _Test(unittest.TestCase):
 
 
 def test_multiprocess_file_handler():
-    logger = LogManager('abcd').get_logger_and_add_handlers(is_add_stream_handler=False, log_filename='amulti_test9.log', log_file_size=100)
+    logger = LogManager('abcd').get_logger_and_add_handlers(is_add_stream_handler=False, log_filename='amulti_test91.log', log_file_size=100)
     t1 = time.time()
-    for i in range(100, 200):
-        # time.sleep(0.000001)
+    for i in range(100000, 200000):
+        time.sleep(0.000001)
         logger.debug(f'{i}a')
         if i % 10000 == 0:
             very_nb_print(i)
@@ -1514,4 +1539,5 @@ def test_multiprocess_file_handler():
 if __name__ == "__main__":
     # unittest.main()
     from multiprocessing import Process
-    [Process(target=test_multiprocess_file_handler).start() for _ in range(10)]
+
+    [Process(target=test_multiprocess_file_handler,).start() for _ in range(10)]
